pub enum CharDecision {
BeginBuffer {
retro_chars: u16,
},
BufferAppend,
RetainFirstChar,
BeginBufferFromPending,
}Variants
BeginBuffer
Start buffering and retroactively capture some already-inserted chars.
BufferAppend
We are currently buffering; append the current char into the buffer.
RetainFirstChar
Do not insert/render this char yet; temporarily save the first fast char while we wait to see if a paste-like burst follows.
BeginBufferFromPending
Begin buffering using the previously saved first char (no retro grab needed).